@@ -16,7 +16,10 @@ func init() {
 			"ExecCmdline": true,
 			"AutoBranch": true,
 			"Dynamic": ({ -> struct-keys }),
-			"Flags": [ "-m", "--merge" ],
+			"FlagsDesc": {
+				"--merge": "Merge data structures rather than overwrite",
+				"--sum": "Sum values in a map, merge items in an array"
+			},
 			"FlagValues": {
 				"-m": [{
 					"AnyValue": true,
@@ -29,6 +32,19 @@ func init() {
 					"ExecCmdline": true,
 					"AutoBranch": true,
 					"Dynamic": ({ -> struct-keys })
+				}],
+
+				"-s": [{
+					"AnyValue": true,
+					"ExecCmdline": true,
+					"AutoBranch": true,
+					"Dynamic": ({ -> struct-keys })
+				}],
+				"--sum": [{
+					"AnyValue": true,
+					"ExecCmdline": true,
+					"AutoBranch": true,
+					"Dynamic": ({ -> struct-keys })
 				}]
 			}
 		} ]}
@@ -39,8 +55,14 @@ func cmdAlter(p *lang.Process) error {
 	dt := p.Stdin.GetDataType()
 	p.Stdout.SetDataType(dt)
 
+	const (
+		alterAlter int = 0
+		alterMerge int = iota + 1
+		alterSum
+	)
+
 	var (
-		merge  bool
+		action int
 		offset int
 	)
 
@@ -59,7 +81,17 @@ func cmdAlter(p *lang.Process) error {
 	}
 
 	if s == "-m" || s == "--merge" {
-		merge = true
+		action = alterMerge
+		offset++
+
+		s, err = p.Parameters.String(1)
+		if err != nil {
+			return err
+		}
+	}
+
+	if s == "-s" || s == "--sum" {
+		action = alterSum
 		offset++
 
 		s, err = p.Parameters.String(1)
@@ -78,13 +110,21 @@ func cmdAlter(p *lang.Process) error {
 		return err
 	}
 
-	if merge {
+	switch action {
+	default:
+		v, err = alter.Alter(p.Context, v, path, new)
+		if err != nil {
+			return err
+		}
+
+	case alterMerge:
 		v, err = alter.Merge(p.Context, v, path, new)
 		if err != nil {
 			return err
 		}
-	} else {
-		v, err = alter.Alter(p.Context, v, path, new)
+
+	case alterSum:
+		v, err = alter.Sum(p.Context, v, path, new)
 		if err != nil {
 			return err
 		}
