@@ -8,13 +8,13 @@ func init() {
 		"2darray":               "Create a 2D JSON array from multiple input sources",
 		"(murex named pipe)":    "Reads from a _murex_ named pipe",
 		"<stdin>":               "Read the STDIN belonging to the parent code block",
-		"=":                     "Evaluate a mathematical function",
+		"=":                     "Evaluate a mathematical function (deprecated)",
 		">>":                    "Writes STDIN to disk - appending contents if file already exists",
 		">":                     "Writes STDIN to disk - overwriting contents if file already exists",
-		"@[":                    "Outputs a ranged subset of data from STDIN",
-		"autoglob":              "Command prefix to expand globbing",
+		"autoglob":              "Command prefix to expand globbing (deprecated)",
 		"[[":                    "Outputs an element from a nested structure",
 		"[":                     "Outputs an element from an array, map or table",
+		"@[":                    "Outputs a ranged subset of data from STDIN",
 		"a":                     "A sophisticated yet simple way to build an array or list",
 		"addheading":            "Adds headings to a table",
 		"alias":                 "Create an alias for a command",
@@ -25,10 +25,12 @@ func init() {
 		"autocomplete":          "Set definitions for tab-completion in the command line",
 		"bexists":               "Check which builtins exist",
 		"bg":                    "Run processes in the background",
+		"break":                 "terminate execution of a block within your processes scope",
 		"cast":                  "Alters the data type of the previous function without altering it's output",
 		"catch":                 "Handles the exception code raised by `try` or `trypipe",
 		"cd":                    "Change (working) directory",
 		"config":                "Query or define _murex_ runtime settings",
+		"continue":              "terminate process of a block within a caller function",
 		"count":                 "Count items in a map, list or array",
 		"cpuarch":               "Output the hosts CPU architecture",
 		"cpucount":              "Output the number of CPU cores available on your host",
@@ -45,6 +47,7 @@ func init() {
 		"exit":                  "Exit murex",
 		"exitnum":               "Output the exit number of the previous process",
 		"export":                "Define an environmental variable and set it's value",
+		"expr":                  "Expressions: mathematical, string comparisons, logical operators",
 		"f":                     "Lists or filters file system objects (eg files)",
 		"false":                 "Returns a `false` value",
 		"fexec":                 "Execute a command or function, bypassing the usual order of precedence.",
@@ -67,7 +70,7 @@ func init() {
 		"ja":                    "A sophisticated yet simply way to build a JSON array",
 		"jsplit":                "Splits STDIN into a JSON array based on a regex parameter",
 		"left":                  "Left substring every item in a list",
-		"let":                   "Evaluate a mathematical function and assign to variable",
+		"let":                   "Evaluate a mathematical function and assign to variable (deprecated)",
 		"lockfile":              "Create and manage lock files",
 		"man-get-flags":         "Parses man page files for command line flags",
 		"man-summary":           "Outputs a man page summary of a command",
@@ -142,14 +145,13 @@ func init() {
 		"fappend":               ">>",
 		">":                     ">",
 		"fwrite":                ">",
-		"@[":                    "@[",
-		"range":                 "@[",
 		"autoglob":              "autoglob",
 		"[[":                    "[[",
 		"element":               "[[",
 		"[":                     "[",
 		"![":                    "[",
 		"index":                 "[",
+		"@[":                    "@[",
 		"a":                     "a",
 		"addheading":            "addheading",
 		"alias":                 "alias",
@@ -163,12 +165,14 @@ func init() {
 		"autocomplete":          "autocomplete",
 		"bexists":               "bexists",
 		"bg":                    "bg",
+		"break":                 "break",
 		"cast":                  "cast",
 		"catch":                 "catch",
 		"!catch":                "catch",
 		"cd":                    "cd",
 		"config":                "config",
 		"!config":               "config",
+		"continue":              "continue",
 		"count":                 "count",
 		"cpuarch":               "cpuarch",
 		"cpucount":              "cpucount",
@@ -191,6 +195,7 @@ func init() {
 		"export":                "export",
 		"!export":               "export",
 		"unset":                 "export",
+		"expr":                  "expr",
 		"f":                     "f",
 		"false":                 "false",
 		"fexec":                 "fexec",
@@ -206,7 +211,6 @@ func init() {
 		"function":              "function",
 		"!function":             "function",
 		"g":                     "g",
-		"@g":                    "g",
 		"!g":                    "g",
 		"get-type":              "get-type",
 		"get":                   "get",
@@ -235,6 +239,7 @@ func init() {
 		"mtac":                  "mtac",
 		"list.reverse":          "mtac",
 		"murex-docs":            "murex-docs",
+		"help":                  "murex-docs",
 		"murex-package":         "murex-package",
 		"murex-parser":          "murex-parser",
 		"murex-update-exe-list": "murex-update-exe-list",
