@@ -1,6 +1,7 @@
 package file
 
 import (
+	"context"
 	"io"
 	"os"
 	"sync"
@@ -24,10 +25,10 @@ func (f *File) Read([]byte) (int, error) { return 0, io.EOF }
 func (f *File) ReadLine(func([]byte)) error { return nil }
 
 // ReadArray is an empty method because file devices are write only
-func (f *File) ReadArray(func([]byte)) error { return nil }
+func (f *File) ReadArray(context.Context, func([]byte)) error { return nil }
 
 // ReadArrayWithType is an empty method because file devices are write only
-func (f *File) ReadArrayWithType(func([]byte, string)) error { return nil }
+func (f *File) ReadArrayWithType(context.Context, func(interface{}, string)) error { return nil }
 
 // ReadMap is an empty method because file devices are write only
 func (f *File) ReadMap(*config.Config, func(string, string, bool)) error { return nil }
