@@ -32,24 +32,32 @@ func NewTee(primary stdio.Io) (primaryTee *Tee, secondaryTee *Stdin) {
 }
 
 // IsTTY calls the primary STDOUT stream in tee to see if it's a TTY
-//func (tee *Tee) IsTTY() bool { retur-n tee.primary.IsTTY() }
+// func (tee *Tee) IsTTY() bool { retur-n tee.primary.IsTTY() }
 func (tee *Tee) IsTTY() bool { return false }
 
 // Stats is stored against the primary STDOUT stream in tee
-func (tee *Tee) Stats() (uint64, uint64) { return tee.primary.Stats() }
+func (tee *Tee) Stats() (uint64, uint64) {
+	return tee.primary.Stats()
+}
 
 // Read from STDIN (uses primary tee stream)
-func (tee *Tee) Read(p []byte) (int, error) { return tee.primary.Read(p) }
+func (tee *Tee) Read(p []byte) (int, error) {
+	return tee.primary.Read(p)
+}
 
 // ReadLine reads a line from STDIN (uses the primary tee stream)
-func (tee *Tee) ReadLine(callback func([]byte)) error { return tee.primary.ReadLine(callback) }
+func (tee *Tee) ReadLine(callback func([]byte)) error {
+	return tee.primary.ReadLine(callback)
+}
 
 // ReadArray reads an array from STDIN (uses the primary tee stream)
-func (tee *Tee) ReadArray(callback func([]byte)) error { return tee.primary.ReadArray(callback) }
+func (tee *Tee) ReadArray(ctx context.Context, callback func([]byte)) error {
+	return tee.primary.ReadArray(ctx, callback)
+}
 
 // ReadArrayWithType reads an array from STDIN (uses the primary tee stream)
-func (tee *Tee) ReadArrayWithType(callback func([]byte, string)) error {
-	return tee.primary.ReadArrayWithType(callback)
+func (tee *Tee) ReadArrayWithType(ctx context.Context, callback func(interface{}, string)) error {
+	return tee.primary.ReadArrayWithType(ctx, callback)
 }
 
 // ReadMap reads a hash table from STDIN (uses the primary tee stream)
@@ -58,7 +66,9 @@ func (tee *Tee) ReadMap(config *config.Config, callback func(string, string, boo
 }
 
 // ReadAll from STDIN (uses the primary tee stream)
-func (tee *Tee) ReadAll() ([]byte, error) { return tee.primary.ReadAll() }
+func (tee *Tee) ReadAll() ([]byte, error) {
+	return tee.primary.ReadAll()
+}
 
 // Write is the standard Writer interface Write() method.
 func (tee *Tee) Write(p []byte) (int, error) {
