@@ -18,6 +18,9 @@ type ErrRed struct {
 	term
 }
 
+// SetDataType is a null method because the term interface is write-only
+func (t *ErrRed) SetDataType(string) {}
+
 // Write is the io.Writer() interface for term
 func (t *ErrRed) Write(b []byte) (i int, err error) {
 	t.mutex.Lock()
