@@ -3,24 +3,37 @@ package jsonlines
 import (
 	"bufio"
 	"bytes"
+	"context"
 
 	"github.com/lmorg/murex/lang/stdio"
 	"github.com/lmorg/murex/lang/types"
 )
 
-func readArray(read stdio.Io, callback func([]byte)) error {
+func readArray(ctx context.Context, read stdio.Io, callback func([]byte)) error {
 	scanner := bufio.NewScanner(read)
 	for scanner.Scan() {
-		callback(bytes.TrimSpace(scanner.Bytes()))
+		select {
+		case <-ctx.Done():
+			return scanner.Err()
+
+		default:
+			callback(bytes.TrimSpace(scanner.Bytes()))
+		}
 	}
 
 	return scanner.Err()
 }
 
-func readArrayWithType(read stdio.Io, callback func([]byte, string)) error {
+func readArrayWithType(ctx context.Context, read stdio.Io, callback func(interface{}, string)) error {
 	scanner := bufio.NewScanner(read)
 	for scanner.Scan() {
-		callback(bytes.TrimSpace(scanner.Bytes()), types.Json)
+		select {
+		case <-ctx.Done():
+			return scanner.Err()
+
+		default:
+			callback(bytes.TrimSpace(scanner.Bytes()), types.Json)
+		}
 	}
 
 	return scanner.Err()
