@@ -14,6 +14,7 @@ import (
 	"github.com/lmorg/murex/lang/runmode"
 	"github.com/lmorg/murex/lang/state"
 	"github.com/lmorg/murex/lang/types"
+	"github.com/lmorg/murex/utils/consts"
 	"github.com/lmorg/murex/utils/json"
 )
 
@@ -44,11 +45,13 @@ func InitEnv() {
 	ShellProcess.Config = config.InitConf
 	ShellProcess.Tests = NewTests(ShellProcess)
 	ShellProcess.Variables = NewVariables(ShellProcess)
-	//ShellProcess.RunMode = runmode.Normal // defaults to Normal due to Normal == 0
 	ShellProcess.Stdout = new(term.Out)
 	ShellProcess.Stderr = term.NewErr(true) // TODO: check this is overridden by `config set ...`
-	ShellProcess.Kill = func() {}
 	ShellProcess.FileRef = &ref.File{Source: &ref.Source{Module: app.ShellModule}}
+	ShellProcess.Context = context.Background()
+	ShellProcess.Done = func() { /* we don't want to accidentally terminate the shell process */ }
+	ShellProcess.Kill = func() { /* we don't want to accidentally terminate the shell process */ }
+	ShellProcess.Forks = NewForkManagement()
 
 	if FlagTry {
 		ShellProcess.RunMode = runmode.ModuleTry
@@ -65,6 +68,15 @@ func InitEnv() {
 	}
 	os.Setenv("SHELL", shellEnv)
 
+	if os.Getenv(consts.EnvMethod) == consts.EnvTrue {
+		ShellProcess.Stdin = term.NewIn(os.Getenv(consts.EnvDataType))
+		ShellProcess.IsMethod = true
+	}
+
+	if os.Getenv(consts.EnvBackground) == consts.EnvTrue {
+		ShellProcess.Background.Set(true)
+	}
+
 	// Pre-populate $PWDHIST with current working directory
 	s, _ := os.Getwd()
 	pwd := []string{s}
@@ -90,6 +102,7 @@ func NewTestProcess() (p *Process) {
 	p.Scope = ShellProcess
 	p.Next = ShellProcess
 	p.Previous = ShellProcess
+	p.Forks = NewForkManagement()
 
 	GlobalFIDs.Register(p)
 
